import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import "x3m.js" as B

Page
{
    id: settingsPage
    tools: commonTools
    orientationLock: PageOrientation.LockPortrait;

    property int streamQuality: 1;
    property alias bufferSize: sBufferSize.value;
    property alias useSurround: surround.checked;
    property alias roomsize: sRoom.value;
    property alias brightness: sBright.value;

    Header {
        id: h
        text: qsTr("Settings");
    }

    Column {
        id: cs
        anchors.top: h.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left;
        anchors.right: parent.right
        anchors.topMargin: B.SMALL_MARGIN
        anchors.leftMargin: B.DEFAULT_MARGIN
        anchors.rightMargin: B.DEFAULT_MARGIN
        spacing: B.SMALL_MARGIN

        Label { text: qsTr("Stream quality"); anchors.left: parent.left; color: "white"; }
        ButtonRow {
            checkedButton: getChecked(streamQuality);
            exclusive: true;
            Button {
                id: sQualityLow
                text: qsTr("Low");
                onCheckedChanged: if (checked) streamQuality=1;
            }
            Button {
                id: sQualityMedium
                text: qsTr("Medium");
                enabled: false
                onCheckedChanged: if (checked) streamQuality=2;
            }
            Button {
                id: sQualityHigh
                text: qsTr("High")
                enabled: false
                onCheckedChanged: if (checked) streamQuality=3;
            }
            function getChecked(sq) {
                switch (sq) {
                case 1:
                    return sQualityLow
                case 2:
                    return sQualityMedium
                case 3:
                    return sQualityHigh
                default: {
                    streamQuality=2;
                    return sQualityMedium;
                }
                }
            }
        }        

        Label { text: qsTr("Buffer size"); anchors.left: parent.left; color: "white"; }
        Slider {
            id: sBufferSize
            width: parent.width-42;
            maximumValue: 20;
            minimumValue: 5;
            height: 32;
            stepSize: 1;
            orientation: Qt.Horizontal
            valueIndicatorVisible: true
        }

        Row {
            width: parent.width
            spacing: B.SMALL_MARGIN
            Label {
                text: qsTr("Surround");
                color: "white";
            }
            Switch {
                id: surround
            }
        }

        Label { text: qsTr("Brightness"); anchors.left: parent.left; color: "white"; }
        Slider {
            id: sBright
            enabled: surround.checked
            width: parent.width-42;
            maximumValue: 4;
            minimumValue: 0;
            height: 32;
            stepSize: 1;
            orientation: Qt.Horizontal
            valueIndicatorVisible: true
        }

        Label { text: qsTr("Roomsize"); anchors.left: parent.left; color: "white"; }
        Slider {
            id: sRoom
            enabled: surround.checked
            width: parent.width-42;
            maximumValue: 4;
            minimumValue: 0;
            height: 32;
            stepSize: 1;
            orientation: Qt.Horizontal
            valueIndicatorVisible: true
        }
    }

}
